@@ -7,3 +7,8 @@ class HttpError(Exception):
     def __init__(self, message, status=http_status.HTTP_400_BAD_REQUEST):
         self.message, self.status = message, status
         super(HttpError, self).__init__(message)
+
+    def __str__(self):
+        return self.message
+
+    __repr__ = __str__
